pub struct SetHeader(/* private fields */);Available on crate feature
set_header only.Implementations
Methods from Deref<Target = AppendOnlyVec<(Box<str>, Box<str>)>>
Sourcepub fn iter(&self) -> impl DoubleEndedIterator + ExactSizeIterator
pub fn iter(&self) -> impl DoubleEndedIterator + ExactSizeIterator
Return an Iterator over the elements of the vec.
Sourcepub fn push(&self, val: T) -> usize
pub fn push(&self, val: T) -> usize
Append an element to the array
This is notable in that it doesn’t require a &mut self, because it
does appropriate atomic synchronization.
The return value is the index tha was pushed to.
Sourcepub fn extend(&self, iter: impl IntoIterator<Item = T>)
pub fn extend(&self, iter: impl IntoIterator<Item = T>)
Extend the vec with the contents of an iterator.
Note: this is currently no more efficient than calling push for each
element of the iterator.